@@ -11,7 +11,7 @@
 //!
 //! This crate is meant for storing small serializable data that stores the state of an application
 //! after exit. Since all the data is loaded
-//! onto memory when calling load on a `Client`, handling large amounts of data is not advised. However,
+//! onto memory when calling load on a `Client<T>`, handling large amounts of data is not advised. However,
 //! the data stored on disk has a relatively small footprint and should not take up that much space.
 //!
 //! Note that this is not an embedded database and there are other libraries which are better suited
@@ -80,7 +80,7 @@ pub enum DatabaseError<T> {
     MismatchedChecksum(#[from] DataPoisonError<T>),
     /// `crio` can only store an object that takes up `u32::MAX` bytes of space. If you run
     /// into this error you should consider some other library.
-    #[error("inserted data too large")]
+    #[error("inserted data too large: object > u32::MAX")]
     DataTooLarge(#[from] TryFromIntError),
     /// Serialization/deserialization error for an object.
     #[error(transparent)]
@@ -187,7 +187,7 @@ where
     ///
     /// # Errors
     ///
-    /// - `DatabaseError<T>::DataTooLarge` occurs when an object you are inserting
+    /// - `std::num::TryFromIntError` occurs when an object you are inserting
     /// takes up more space than `u32::MAX` bytes. In that case, seek help.
     ///
     /// - The usual `std::io::Error` such as `ErrorKind::UnexpectedEof` if the file
